import { EventProperties, Traits, Emitter, CoreAnalytics, CoreContext, CorePlugin, EventQueue, CoreOptions, Callback, CoreSegmentEvent, CoreEmitterContract } from '@segment/analytics-core';
import { AnalyticsSettings } from './settings';
export declare class Context extends CoreContext {
}
/**
 * An ID associated with the user. Note: at least one of userId or anonymousId must be included.
 **/
declare type IdentityOptions = {
    userId: string;
    anonymousId?: string;
} | {
    userId?: string;
    anonymousId: string;
};
/** Events from CoreOptions */
export interface SegmentEventOptions {
    context?: Context;
    timestamp?: CoreOptions['timestamp'];
}
/**
 * Map of emitter event names to method args.
 */
declare type NodeEmitterEvents = CoreEmitterContract<Context> & {
    initialize: [AnalyticsSettings];
    call_after_close: [SegmentEvent];
    drained: [];
};
declare type SegmentEventType = 'track' | 'page' | 'identify' | 'alias' | 'screen';
export interface SegmentEvent extends CoreSegmentEvent {
    type: SegmentEventType;
    options?: SegmentEventOptions;
}
export declare class Analytics extends Emitter<NodeEmitterEvents> implements CoreAnalytics {
    private _eventFactory;
    private _isClosed;
    private _pendingEvents;
    private readonly _closeAndFlushDefaultTimeout;
    queue: EventQueue;
    ready: Promise<void>;
    constructor(settings: AnalyticsSettings);
    get VERSION(): string;
    /**
     * Call this method to stop collecting new events and flush all existing events.
     * This method also waits for any event method-specific callbacks to be triggered,
     * and any of their subsequent promises to be resolved/rejected.
     */
    closeAndFlush({ timeout, }?: {
        /** Set a maximum time permitted to wait before resolving. */
        timeout?: number;
    }): Promise<void>;
    private _dispatch;
    /**
     * Combines two unassociated user identities.
     * @link https://segment.com/docs/connections/sources/catalog/libraries/server/node/#alias
     */
    alias({ userId, previousId, options, callback, }: {
        userId: string;
        previousId: string;
        options?: SegmentEventOptions;
        callback?: Callback;
    }): void;
    /**
     * Associates an identified user with a collective.
     *  @link https://segment.com/docs/connections/sources/catalog/libraries/server/node/#group
     */
    group({ groupId, userId, anonymousId, traits, options, callback, }: IdentityOptions & {
        groupId: string;
        traits?: Traits;
        options?: SegmentEventOptions;
        callback?: Callback;
    }): void;
    /**
     * Includes a unique userId and (maybe anonymousId) and any optional traits you know about them.
     * @link https://segment.com/docs/connections/sources/catalog/libraries/server/node/#identify
     */
    identify({ userId, anonymousId, traits, options, callback, }: IdentityOptions & {
        traits?: Traits;
        options?: SegmentEventOptions;
        callback?: Callback;
    }): void;
    /**
     * The page method lets you record page views on your website, along with optional extra information about the page being viewed.
     * @link https://segment.com/docs/connections/sources/catalog/libraries/server/node/#page
     */
    page({ userId, anonymousId, category, name, properties, options, timestamp, callback, }: IdentityOptions & {
        category?: string;
        name?: string;
        properties?: EventProperties;
        callback?: Callback;
        timestamp?: string | Date;
        options?: SegmentEventOptions;
    }): void;
    /**
     * Records screen views on your app, along with optional extra information
     * about the screen viewed by the user.
     *
     * TODO: This is not documented on the segment docs ATM (for node).
     */
    screen({ userId, anonymousId, category, name, properties, options, callback, timestamp, }: Parameters<Analytics['page']>[0]): void;
    /**
     * Records actions your users perform.
     * @link https://segment.com/docs/connections/sources/catalog/libraries/server/node/#track
     */
    track({ userId, anonymousId, event, properties, options, callback, }: IdentityOptions & {
        event: string;
        properties?: EventProperties;
        options?: SegmentEventOptions;
        callback?: Callback;
    }): void;
    /**
     * Registers one or more plugins to augment Analytics functionality.
     * @param plugins
     */
    register(...plugins: CorePlugin<any, any>[]): Promise<void>;
    /**
     * Deregisters one or more plugins based on their names.
     * @param pluginNames - The names of one or more plugins to deregister.
     */
    deregister(...pluginNames: string[]): Promise<void>;
}
export {};
//# sourceMappingURL=analytics-node.d.ts.map